==> ember-simple-auth-4.0.2.tgz: package/tests/unit/session-stores/cookie-test.js <==
import { describe } from 'mocha';
import itBehavesLikeAStore from './shared/store-behavior';
import itBehavesLikeACookieStore from './shared/cookie-store-behavior';
import FakeCookieService from '../../helpers/fake-cookie-service';
import CookieStore from 'ember-simple-auth/session-stores/cookie';
import { setupTest } from 'ember-mocha';

describe('CookieStore', () => {
  setupTest();

  describe('StoreBehavior', function() {
    itBehavesLikeAStore({
      store(sinon, owner) {
        let store;
        let cookieService;
        owner.register('service:cookies', FakeCookieService);
        cookieService = owner.lookup('service:cookies');
        sinon.spy(cookieService, 'read');
        sinon.spy(cookieService, 'write');
        owner.register('session-store:cookie', CookieStore.extend({
          _cookieName: 'test-session',
        }));
        store = owner.lookup('session-store:cookie');
        return store;
      },
      syncExternalChanges(store) {
        store._syncData();
      }
    });
  });

  describe('CookieStoreBehavior', function() {
    itBehavesLikeACookieStore({
      store(sinon, owner, storeOptions) {
        owner.register('service:cookies', FakeCookieService);
        let cookieService = owner.lookup('service:cookies');
        sinon.spy(cookieService, 'read');
        sinon.spy(cookieService, 'write');
        owner.register('session-store:cookie', CookieStore.extend(Object.assign({
          _cookieName: 'test:session',
        }, storeOptions)));
        let store = owner.lookup('session-store:cookie');
        return store;
      },
      createStore(store) {
        return store;
      },
      renew(store, data) {
        return store._renew(data);
      },
      sync(store) {
        store._syncData();
      },
      spyRewriteCookieMethod(sinon, store) {
        sinon.spy(store, 'rewriteCookie');
        return store.rewriteCookie;
      }
    });
  });
});

==> ember-simple-auth-4.2.0.tgz: package/tests/unit/session-stores/cookie-test.js <==
import { module } from 'qunit';
import { setupTest } from 'ember-qunit';
import itBehavesLikeAStore from './shared/store-behavior';
import itBehavesLikeACookieStore from './shared/cookie-store-behavior';
import FakeCookieService from '../../helpers/fake-cookie-service';
import CookieStore from 'ember-simple-auth/session-stores/cookie';
import assign from 'ember-simple-auth/utils/assign';

module('CookieStore', function(hooks) {
  setupTest(hooks);

  module('StoreBehavior', function(hooks) {
    itBehavesLikeAStore({
      hooks,
      store(sinon, owner) {
        let store;
        let cookieService;
        owner.register('service:cookies', FakeCookieService);
        cookieService = owner.lookup('service:cookies');
        sinon.spy(cookieService, 'read');
        sinon.spy(cookieService, 'write');
        owner.register('session-store:cookie', CookieStore.extend({
          _cookieName: 'test-session',
        }));
        store = owner.lookup('session-store:cookie');
        return store;
      },
      syncExternalChanges(store) {
        store._syncData();
      }
    });
  });

  module('CookieStoreBehavior', function(hooks) {
    itBehavesLikeACookieStore({
      hooks,
      store(sinon, owner, storeOptions) {
        owner.register('service:cookies', FakeCookieService);
        let cookieService = owner.lookup('service:cookies');
        sinon.spy(cookieService, 'read');
        sinon.spy(cookieService, 'write');
        owner.register('session-store:cookie', CookieStore.extend(assign({
          _cookieName: 'test:session',
        }, storeOptions)));
        let store = owner.lookup('session-store:cookie');
        return store;
      },
      createStore(store) {
        return store;
      },
      renew(store, data) {
        return store._renew(data);
      },
      sync(store) {
        store._syncData();
      },
      spyRewriteCookieMethod(sinon, store) {
        sinon.spy(store, 'rewriteCookie');
        return store.rewriteCookie;
      }
    });
  });
});
